@@ -11,7 +11,7 @@ class FusionMask(Fusion):
     def __init__(self, pet, mask, target_size=None, target_spacing=None, target_direction=None, mode = 'dict'):
         #super().__init__()
         self.pet_objet = pet
-        self.mask_object = mask
+        self.ct_object = mask #change name in Fusion 
         self.target_size = target_size
         self.target_spacing = target_spacing
         self.target_direction = target_direction
@@ -38,8 +38,8 @@ class FusionMask(Fusion):
             liste = []
             for roi in range(mask_size[3]):
                 extract = sitk.ExtractImageFilter()
-                extract.setSize([mask_size[0], mask_size[1], mask_size[2], 0])
-                extract.setIndex([0,0,0,roi])
+                extract.SetSize([mask_size[0], mask_size[1], mask_size[2], 0])
+                extract.SetIndex([0,0,0,roi])
                 extracted_img = extract.Execute(mask_img)
                 transformation = sitk.ResampleImageFilter()
                 transformation.SetOutputDirection(target_direction)
